const defaultTheme = require('tailwindcss/defaultTheme');

const allColors = [
  'transparent',
  'current',
  'primary',
  'primary-100',
  'primary-200',
  'primary-300',
  'secondary',
  'secondary-100',
  'secondary-200',
  'secondary-300',
  'tertiary',
  'tertiary-100',
  'tertiary-200',
  'tertiary-300',
  'accent',
  'accent-focus',
  'accent-content',
  'base-100',
  'base-200',
  'base-300',
  'base-400',
  'base-500',
  'base-600',
  'base-700',
  'base-800',
  'base-900',
  'base-1000',
  'base-11000',
  'base-content',
  'base-content-secondary',
  'base-content-invert',
  'info',
  'info-hover',
  'success',
  'success-hover',
  'warning',
  'error',
  'error-hover',
  'error-text',
  'focus',
  'link',
  'link-hover',
  'link-visited',
  'link-active',
  'white',
  'gray-100',
  'gray-200',
  'gray-300',
  'gray-400',
  'gray-500',
  'gray-600',
  'gray-700',
  'gray-800',
  'gray-900',
  'gray-1000',
  'gray-1100',
  'gray-1200',
  'black',
  'shadow200',
  'shadow600',
];

const colorVariables = allColors.reduce((colorVars, color) => {
  if (['transparent', 'currentColor'].includes(color)) {
    colorVars[color] = color;
  } else {
    colorVars[color] = ({ opacityVariable, opacityValue }) => {
      if (opacityValue !== undefined) {
        return `rgba(var(--color-${color}-rgb), ${opacityValue})`;
      }
      if (opacityVariable !== undefined) {
        return `rgba(var(--color-${color}-rgb), var(${opacityVariable}, 1))`;
      }
      return `rgb(var(--color-${color}-rgb))`;
    };
  }
  return colorVars;
}, {});

const screens = require('./screens.json');
const screensWithPixels = Object.keys(screens).reduce((screenVars, screen) => {
  screenVars[screen] = `${screens[screen]}px`;
  return screenVars;
}, {});

/** @type {import('tailwindcss').Config} */
module.exports = {
  darkMode: 'class',
  content: {
    files: ['./src/*.css'],
    relative: true,
  },
  theme: {
    colors: colorVariables,
    screens: {
      ...screensWithPixels,
      print: { raw: 'print' },
      xsOnly: { min: '0px', max: '639.98px' },
      smOnly: { min: '640px', max: '767.98px' },
      mdOnly: { min: '768px', max: '1023.98px' },
      lgOnly: { min: '1024px', max: '1279.98px' },
      xlOnly: { min: '1280px', max: '1535.98px' },
    },
    container: {
      center: true,
    },
    fontSize: {
      ...defaultTheme.fontSize,
      lg: '1.1875rem',
    },
    fontFamily: {
      sans: ['Roboto', ...defaultTheme.fontFamily.sans],
    },
    extend: {
      height: {
        fit: 'fit-content',
      },
      width: {
        fit: 'fit-content',
        '2xl': '42rem',
        '4xl': '56rem',
      },
      maxWidth: {
        fit: 'fit-content',
      },
      minWidth: {
        4: '1rem',
        10: '2.5rem',
        12: '3rem',
        32: '8rem',
        52: '13rem',
      },
      minHeight: {
        4: '1rem',
        6: '1.5rem',
        8: '2rem',
        10: '2.5rem',
        12: '3rem',
        14: '3.5rem',
      },
      borderWidth: {
        3: '3px',
        5: '5px',
        6: '6px',
      },
      flexGrow: {
        2: '2',
      },
      zIndex: {
        '/1': -1,
        1: 1,
        2: 2,
        3: 3,
        5: 5,
      },
      opacity: {
        85: '0.85',
      },
      margin: {
        15: '3.75rem',
      },
      boxShadow: {
        thick: '0 0 30px rgba(0, 0, 0, 0.6)',
      },
    },
  },
};
